<?php

namespace Drupal\bmm\Commands;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drush\Commands\DrushCommands;
use Drupal\Core\Database\Connection;

/**
 * Class SessionsCommand.
 */
class SessionsCommand extends DrushCommands {

  /**
   * The database connection to use.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * The entity type manager object.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * SubscriptionsCommand constructor.
   */
  public function __construct(Connection $connection, EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
    $this->connection = $connection;
  }

  /**
   * Drush command clear current sessions.
   *
   * @command udw-sessions:clear
   * @aliases udwsc
   * @usage udw-sessions:clear
   */
  public function clear() {
    $query = $this->connection->select('sessions', 's');
    $query->leftJoin('users_field_data', 'u', 'u.uid = s.uid');
    $query->condition('s.uid', 1, '<>');
    $query->fields('s', ['uid']);
    $query->fields('u', ['name']);
    $result = $query->execute()->fetchAll();
    // Destroy sessions.
    if (!empty($result)) {
      foreach ($result as $session) {
        // We can't use session_manager here because it has $this->isCli()
        // condition which does not allow to clear the session. That is why
        // it's set to direct query as Drupal\Core\Session delete method does.
        // Check https://bit.ly/37fsvSG for details.
        $this->connection
          ->delete('sessions')
          ->condition('uid', $session->uid)
          ->execute();
      }
      $this->logger()->success(dt('@number of users has been logged out.', ['@number' => count($result)]));
    }
    else {
      $this->logger()->success(dt('None of the users has been logged in.'));
    }
  }

}
